@@ -25,14 +25,27 @@ def clear():
 		system('clear')
 	else:
 		system('cls')
-clear()
 
-f = open("client_secret.json", "r+")
-f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
-f.flush()
+try:
+	f = open("client_secret.json", "r+")
+	f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
+	f.flush()
+	gc = pygsheets.authorize()
+	f.close()
+except:
+	pass
+
+def load_client_secret(path):
+	f = open(path, "r+")
+	f.write("{\"installed\":{\"client_id\":\"376353198664-o1v3m5ldtlaafq5rubfkmim13glspohr.apps.googleusercontent.com\",\"project_id\":\"gcoin-328514\",\"auth_uri\":\"https://accounts.google.com/o/oauth2/auth\",\"token_uri\":\"https://oauth2.googleapis.com/token\",\"auth_provider_x509_cert_url\":\"https://www.googleapis.com/oauth2/v1/certs\",\"client_secret\":\"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\",\"redirect_uris\":[\"urn:ietf:wg:oauth:2.0:oob\",\"http://localhost\"]}}")
+	f.flush()
+	return 1
+
 gc = pygsheets.authorize()
-f.close()
-
+try:
+	f.close()
+except:
+	pass
 sh = gc.open("GCoin DB")
 wk1 = sh.sheet1
 
@@ -72,8 +85,8 @@ def create_account(key):
 			wk1.update_value(str(wk1.cell((i, 1)))[6:8], i - 1)
 			wk1.update_value(str(wk1.cell((i, 2)))[6:8], key)
 			wk1.update_value(str(wk1.cell((i, 3)))[6:8], 0)
-			wk1.update_value(str(wk1.cell((i, 4)))[6:8], 0)
-			return 1
+			wk1.update_value(str(wk1.cell((i, 4)))[6:8], 0.01)
+			return i - 1
 
 def balance():
 	return float(wk1.cell((account.__id__, 3)).value)
@@ -92,28 +105,22 @@ def send_gcoin(recipientid, amount):
 
 def mine():
 	account.__mining__ = True
-	guessme = randint(0, 50)
+	guessme = randint(0, 100)
 	successes = 0
 	earnings = 0
-	while account.__mining__ == True:
-		guess = randint(0, 50)
-		clear()
-		if guess == guessme:
-			mine_info.is_correct = True
-			successes += 1
-			earnings += 0.01
-			wk1.update_value(str(wk1.cell((account.__id__, 3)))[6:8], float(wk1.cell((account.__id__, 3)).value) + 0.01)
-			guessme = randint(0, 50)
-			mine_info.currentguess = guess
-			mine_info.successes = successes
-			mine_info.earnings = earnings
-			time.sleep(0.05)
-			mine_info.is_correct = False
-		else:
-			mine_info.currentguess = guess
-			mine_info.successes = successes
-			mine_info.earnings = earnings
-			time.sleep(0.05)
-
-def stop_mine():
+	guess = randint(0, 100)
+	if guess == guessme:
+		mine_info.is_correct = True
+		successes += 1
+		earnings += float(wk1.cell((account.__id__, 4)).value)
+		wk1.update_value(str(wk1.cell((account.__id__, 3)))[6:8], float(wk1.cell((account.__id__, 3)).value) + float(wk1.cell((account.__id__, 4)).value))
+		guessme = randint(0, 100)
+		mine_info.currentguess = guess
+		mine_info.successes += successes
+		mine_info.earnings += earnings
+		time.sleep(0.05)
+	else:
+		mine_info.is_correct = False
+		mine_info.currentguess = guess
+		time.sleep(0.05)
 	account.__mining__ = False
\ No newline at end of file
